@@ -27,6 +27,9 @@ class ND2Reader(FramesSequenceND):
         # Setup the axes
         self._setup_axes()
 
+        # Other properties
+        self._timesteps = None
+
     @classmethod
     def class_exts(cls):
         """Let PIMS open function use this reader for opening .nd2 files
@@ -61,7 +64,11 @@ class ND2Reader(FramesSequenceND):
             numpy.ndarray: The requested frame
 
         """
-        c_name = self.metadata["channels"][c]
+        try:
+            c_name = self.metadata["channels"][c]
+        except KeyError:
+            c_name = self.metadata["channels"][0]
+
         x = self.metadata["width"] if x <= 0 else x
         y = self.metadata["height"] if y <= 0 else y
         return self._parser.get_image_by_attributes(t, 0, c_name, z, y, x)
@@ -85,6 +92,27 @@ class ND2Reader(FramesSequenceND):
         """
         return self._dtype
 
+    @property
+    def timesteps(self):
+        """Get the timesteps of the experiment
+
+        Returns:
+            np.ndarray: an array of times in milliseconds.
+
+        """
+        if self._timesteps is None:
+            return self.get_timesteps()
+        return self._timesteps
+
+    @property
+    def frame_rate(self):
+        """The (average) frame rate
+        
+        Returns:
+            float: the (average) frame rate in frames per second
+        """
+        return 1000. / np.mean(np.diff(self.timesteps))
+
     def _get_metadata_property(self, key, default=None):
         if self.metadata is None:
             return default
@@ -103,9 +131,9 @@ class ND2Reader(FramesSequenceND):
         """
         self._init_axis_if_exists('x', self._get_metadata_property("width", default=0))
         self._init_axis_if_exists('y', self._get_metadata_property("height", default=0))
-        self._init_axis_if_exists('c', len(self._get_metadata_property("channels", default=[])))
+        self._init_axis_if_exists('c', len(self._get_metadata_property("channels", default=[])), min_size=2)
         self._init_axis_if_exists('t', len(self._get_metadata_property("frames", default=[])))
-        self._init_axis_if_exists('z', len(self._get_metadata_property("z_levels", default=[])))
+        self._init_axis_if_exists('z', len(self._get_metadata_property("z_levels", default=[])), min_size=2)
 
         if len(self.sizes) == 0:
             raise EmptyFileError("No axes were found for this .nd2 file.")
@@ -113,8 +141,8 @@ class ND2Reader(FramesSequenceND):
         # provide the default
         self.iter_axes = self._guess_default_iter_axis()
 
-    def _init_axis_if_exists(self, axis, size):
-        if size > 0:
+    def _init_axis_if_exists(self, axis, size, min_size=1):
+        if size >= min_size:
             self._init_axis(axis, size)
 
     def _guess_default_iter_axis(self):
@@ -145,6 +173,9 @@ class ND2Reader(FramesSequenceND):
             np.ndarray: an array of times in milliseconds.
 
         """
+        if self._timesteps is not None:
+            return self._timesteps
+
         timesteps = np.array([])
         current_time = 0.0
         for loop in self.metadata['experiment']['loops']:
@@ -161,4 +192,5 @@ class ND2Reader(FramesSequenceND):
             current_time += loop['duration']
 
         # if experiment did not finish, number of timesteps is wrong. Take correct amount of leading timesteps.
-        return timesteps[:self.metadata['num_frames']]
+        self._timesteps = timesteps[:self.metadata['num_frames']]
+        return self._timesteps
